'''
# @affinidi/common-check-widget-backend-lib [![NPM](https://img.shields.io/npm/v/jsii-code-samples)](https://www.npmjs.com/package/@affinidi/common-check-widget-backend-lib) [![PyPI](https://img.shields.io/pypi/v/aws-jsiisamples.jsii-code-samples)](https://pypi.org/project/common-check-widget-backend-lib) [![Maven](https://img.shields.io/maven-central/v/software.aws.jsiisamples.jsii/jsii-code-samples)](https://search.maven.org/artifact/common.check.widget.backend.lib/backend-ib) [![NuGet](https://img.shields.io/nuget/v/AWSSamples.Jsii)](https://www.nuget.org/packages/CCW.Jsii%22)

> An common-check-widget-backend-lib package authored in TypeScript that gets published as GitHub packages for Node.js, Python etc

## License

This library is licensed under the MIT-0 License. See the LICENSE file.

## Coming soon
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ._jsii import *


class CommonCheckWidget(
    metaclass=jsii.JSIIMeta,
    jsii_type="@affinidi/common-check-widget-backend-lib.CommonCheckWidget",
):
    def __init__(self) -> None:
        jsii.create(CommonCheckWidget, self, [])

    @jsii.member(jsii_name="ccw")
    def ccw(self, encryption_file: typing.Any, callback: typing.Any) -> None:
        '''
        :param encryption_file: -
        :param callback: -
        '''
        return typing.cast(None, jsii.invoke(self, "ccw", [encryption_file, callback]))

    @jsii.member(jsii_name="ccwasync")
    def ccwasync(self, encryption_file: typing.Any) -> typing.Any:
        '''
        :param encryption_file: -
        '''
        return typing.cast(typing.Any, jsii.ainvoke(self, "ccwasync", [encryption_file]))

    @jsii.member(jsii_name="ccwbypath")
    def ccwbypath(self, path: typing.Any, callback: typing.Any) -> None:
        '''
        :param path: -
        :param callback: -
        '''
        return typing.cast(None, jsii.invoke(self, "ccwbypath", [path, callback]))

    @jsii.member(jsii_name="ccwbypathasync")
    def ccwbypathasync(self, path: typing.Any) -> typing.Any:
        '''
        :param path: -
        '''
        return typing.cast(typing.Any, jsii.ainvoke(self, "ccwbypathasync", [path]))

    @jsii.member(jsii_name="ccwbypathid")
    def ccwbypathid(
        self,
        path: typing.Any,
        request_id: typing.Any,
        callback: typing.Any,
    ) -> None:
        '''
        :param path: -
        :param request_id: -
        :param callback: -
        '''
        return typing.cast(None, jsii.invoke(self, "ccwbypathid", [path, request_id, callback]))

    @jsii.member(jsii_name="ccwbypathidasync")
    def ccwbypathidasync(self, path: typing.Any, request_id: typing.Any) -> typing.Any:
        '''
        :param path: -
        :param request_id: -
        '''
        return typing.cast(typing.Any, jsii.ainvoke(self, "ccwbypathidasync", [path, request_id]))

    @jsii.member(jsii_name="ccwerror")
    def ccwerror(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.invoke(self, "ccwerror", []))

    @jsii.member(jsii_name="ccwid")
    def ccwid(
        self,
        encryption_file: typing.Any,
        request_id: typing.Any,
        callback: typing.Any,
    ) -> None:
        '''
        :param encryption_file: -
        :param request_id: -
        :param callback: -
        '''
        return typing.cast(None, jsii.invoke(self, "ccwid", [encryption_file, request_id, callback]))

    @jsii.member(jsii_name="ccwidasync")
    def ccwidasync(
        self,
        encryption_file: typing.Any,
        request_id: typing.Any,
    ) -> typing.Any:
        '''
        :param encryption_file: -
        :param request_id: -
        '''
        return typing.cast(typing.Any, jsii.ainvoke(self, "ccwidasync", [encryption_file, request_id]))


__all__ = [
    "CommonCheckWidget",
]

publication.publish()



import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "affinidi.common-check-widget-backend-lib",
    "version": "1.1.6",
    "description": "An common-check-widget-backend-lib used to development backend for common-check-widget-frontend",
    "license": "MIT-0",
    "url": "https://gitlab.com/affinidi/safe-travel/st-experiments/common-check-widget-backend-lib",
    "long_description_content_type": "text/markdown",
    "author": "Chai Jian Wei<jianwei.c@affinidi.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://gitlab.com/affinidi/safe-travel/st-experiments/common-check-widget-backend-lib.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "affinidi.common_check_widget_backend_lib",
        "affinidi.common_check_widget_backend_lib._jsii"
    ],
    "package_data": {
        "affinidi.common_check_widget_backend_lib._jsii": [
            "common-check-widget-backend-lib@1.1.6.jsii.tgz"
        ],
        "affinidi.common_check_widget_backend_lib": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii>=1.32.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
